# Change Log

## 0.1.3
- Change the content type of long_description to text/markdown

## 0.1.2
- Added the content of README.md as the long_description field to setup.py as requested by https://github.com/lektor/lektor-website/issues/203

## 0.1.1
- Fixed bugs in README.md.
- Added a working Parcel example.

## 0.1
- Initial release
